@@ -102,6 +102,8 @@ class Client:
             self._client = await self.aiohttp_session.ws_connect(
                 self.ws_server_url,
                 heartbeat=55,
+                compress=15,
+                max_msg_size=0,
             )
         except (
             client_exceptions.WSServerHandshakeError,
@@ -224,6 +226,7 @@ class Client:
 
             for future in self._result_futures.values():
                 future.cancel()
+            self._result_futures.clear()
 
             if not self._client.closed:
                 await self._client.close()
@@ -249,6 +252,9 @@ class Client:
         await self._client.close()
         await self._shutdown_complete_event.wait()
 
+        self._shutdown_complete_event = None
+        self.driver = None
+
     async def _receive_json_or_raise(self) -> dict:
         """Receive json or raise."""
         assert self._client
