@@ -46,6 +46,10 @@ LOCK_CMD_CLASS_TO_PROPERTY_MAP = {
 
 LOCK_USERCODE_PROPERTY = "userCode"
 LOCK_USERCODE_STATUS_PROPERTY = "userIdStatus"
+DOOR_STATUS_PROPERTY = "doorStatus"
+CURRENT_MODE_PROPERTY = "currentMode"
+LOCKED_PROPERTY = "locked"
+
 ATTR_CODE_SLOT = "code_slot"
 ATTR_IN_USE = "in_use"
 ATTR_NAME = "name"
